# nxs-analysis-tools

## Overview

nxs-analysis-tools provides a suite of tools for slicing (2D) cutting (1D) and transforming (e.g., symmetrizing, interpolating, deltaPDF) nexus format (.nxs) scattering data.


View the documentation [here](https://nxs-analysis-tools.readthedocs.io/en/stable/).

## Installation

Install nxs-analysis-tools with ``pip``:

```{code-block} console
pip install nxs_analysis_tools
```
For a manual install get this package:

```{code-block} console

    wget https://github.com/stevenjgomez/nxs_analysis_tools/archive/master.zip
    unzip master.zip
    rm master.zip
    cd nxs_analysis_tools-master
```

## License

This project is licensed under the MIT License.
